#!/bin/bash

#############################################################################
## VRL-Studio Installer                                                     # 
##  * Copyright (c) 2009–2014 Steinbeis Forschungszentrum (STZ Ölbronn),    #
##  * Copyright (c) 2006–2014 by Michael Hoffer (info@michaelhoffer.de)     #                                   
#############################################################################

OS=$(uname -a)

CALL_PATH=$(pwd)

APPDIR="$(dirname "$0")/.application"
cd "$APPDIR"
APPDIR="$(pwd)"

if [ "$1" == "--install" ] || [ "$1" == "-i" ]
then

if [[ $OS == *Linux* ]]
then
  echo ">> detected linux, installing mime-type"
  
  xdg-icon-resource install --size 128 resources/mime/pm-app-icon.png promesh --novendor
  xdg-icon-resource install --context mimetypes --size 128 resources/mime/pm-file-icon.png application-x-ugx
  
  cp resources/mime/promesh-template.desktop resources/mime/promesh.desktop
  cp resources/mime/application-x-ugx-template.xml resources/mime/application-x-ugx.xml
 
  EXEC=$(echo "$APPDIR/../ProMesh4.sh"| sed 's/\//\\\//g')
  FILE_ICON=$(echo "$APPDIR/resources/mime/pm-file-icon.png"| sed 's/\//\\\//g')
  APP_ICON=$(echo "$APPDIR/resources/mime/pm-app-icon.png"| sed 's/\//\\\//g')

  sed -i "s/APPLICATION_NAME/$EXEC/g" resources/mime/promesh.desktop
  sed -i "s/APP_ICON_NAME/$APP_ICON/g" resources/mime/promesh.desktop
  sed -i "s/FILE_ICON_NAME/$FILE_ICON/g" resources/mime/application-x-ugx.xml

  xdg-mime install resources/mime/application-x-ugx.xml

  xdg-desktop-menu install resources/mime/promesh.desktop --novendor
  update-mime-database $HOME/.local/share/mime/
  update-desktop-database $HOME/.local/share/applications

  exit 0
else
  echo ">> not running on linux, cannot install mime-type"
  exit 1
fi

fi # end install

if [ "$1" == "--uninstall" ] || [ "$1" == "-u" ]
then

if [[ $OS == *Linux* ]]
then
  echo ">> detected linux, uninstalling mime-type"

  xdg-mime uninstall resources/mime/application-x-ugx.xml
  xdg-icon-resource uninstall --size 128 promesh --novendor
  xdg-icon-resource uninstall --context mimetypes --size 128 application-x-ugx
  xdg-desktop-menu uninstall resources/mime/promesh.desktop
  update-mime-database $HOME/.local/share/mime/
  update-desktop-database $HOME/.local/share/applications

  exit 0
else
  echo ">> not running on linux, cannot uninstall mime-type"

  exit 1
fi

fi


if [ "$1" == "--help" ]  || [ "$1" == "-h" ]
then

cat << EOF

** Help: **

Usage:	

Installation (Linux only):

./setup.sh --install        Registers the application with the Desktop and
                            installs MIME Type information

./setup.sh --uninstall      Unregisters the application from the Desktop and
                            uninstalls MIME Type information

./setup.sh --help           Shows this help message

./setup.sh -i               Same as '--install'

./setup.sh -u               Same as '--uninstall'

./setup.sh -h               Same as '--help'


EOF

exit 0

fi

echo ">> No argument specified. Type './setup --install' to install ProMesh. Type './setup.sh --help' for more information."
exit 1
